@@ -2,7 +2,7 @@ package Geo::Coder::Google::V3;
 
 use strict;
 use warnings;
-our $VERSION = '0.14_02';
+our $VERSION = '0.15_01';
 
 use Carp;
 use Encode;
@@ -111,7 +111,9 @@ sub geocode {
     my $json = JSON->new->utf8;
     my $data = $json->decode($res->content);
 
-    Carp::croak(sprintf "Google Maps API returned status '%s'", $data->{status}) unless $data->{status} eq 'OK';
+    unless ($data->{status} eq 'OK' || $data->{status} eq 'ZERO_RESULTS') {
+        Carp::croak(sprintf "Google Maps API returned status '%s'", $data->{status});
+    }
 
     my @results = @{ $data->{results} || [] };
     wantarray ? @results : $results[0];
